Prediction class

Constructors

Prediction({String? id, String? displayName, String? formattedAddress, List<AddressComponents>? addressComponents})
Prediction.fromJson(Map<String, dynamic> json)

Properties

addressComponents List<AddressComponents>?
getter/setter pair
displayName String?
getter/setter pair
formattedAddress String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited